==> haskell-bv-sized-1.0.2-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bv-sized
version:              1.0.2
visibility:           public
id:                   bv-sized-1.0.2-7Mymd357TQa3AH1hkWmIea
key:                  bv-sized-1.0.2-7Mymd357TQa3AH1hkWmIea
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  60934b79f37d646714533692f8306398
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-8.10.4/site-local/bv-sized-1.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bv-sized-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/bv-sized-1.0.2
hs-libraries:         HSbv-sized-1.0.2-7Mymd357TQa3AH1hkWmIea
depends:
    base-4.14.1.0 bitwise-1.0.0.1-JC3QdthSsay52xfJQKjkCB
    bytestring-0.10.12.0 panic-0.4.0.1-Fo4sCfDqcEkCpAt882LFEy
    parameterized-utils-2.1.3.0-7A6UmKu25Nk2mkLk7DuNzD
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bv-sized-1.0.2-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bv-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bv-sized
version:              1.0.2
visibility:           public
id:                   bv-sized-1.0.2-DjQl79lFO7DLJQs8ScVreA
key:                  bv-sized-1.0.2-DjQl79lFO7DLJQs8ScVreA
license:              BSD-3-Clause
copyright:            Galois Inc., Ben Selfridge March 2018
maintainer:           benselfridge@galois.com
author:               Ben Selfridge
homepage:             https://github.com/GaloisInc/bv-sized
synopsis:
    a bitvector datatype that is parameterized by the vector width

description:
    This module defines a width-parameterized bitvector type and various associated operations.

category:             Bit Vectors
abi:                  d760f140ac0023677eff10c3ba6dc9b0
exposed:              True
exposed-modules:
    Data.BitVector.Sized Data.BitVector.Sized.Overflow
    Data.BitVector.Sized.Signed Data.BitVector.Sized.Unsigned

hidden-modules:
    Data.BitVector.Sized.Internal Data.BitVector.Sized.Panic

import-dirs:          /usr/lib/ghc-8.10.4/site-local/bv-sized-1.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/bv-sized-1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/bv-sized-1.0.2
hs-libraries:         HSbv-sized-1.0.2-DjQl79lFO7DLJQs8ScVreA
depends:
    base-4.14.1.0 bitwise-1.0.0.1-JC3QdthSsay52xfJQKjkCB
    bytestring-0.10.12.0 panic-0.4.0.1-Fo4sCfDqcEkCpAt882LFEy
    parameterized-utils-2.1.3.0-4eQgW6fs9RqLPsiWChd2Vu
    th-lift-0.8.2-7d37mrJ37yC1VcDgqjDphG

haddock-interfaces:   /usr/share/doc/haskell-bv-sized/html/bv-sized.haddock
haddock-html:         /usr/share/doc/haskell-bv-sized/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
